Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(261)

Unified Diff: third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp

Issue 1897193002: Worker: Rename worker components to clarify what they work for (part 2) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThread.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp
diff --git a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp
index 534df2fa5eaa15d35f0bc0b47d5775489146ebd4..5ff366c8418fe82d753ba7743e744c0db024f3fc 100644
--- a/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp
+++ b/third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThreadTest.cpp
@@ -8,9 +8,9 @@
#include "bindings/core/v8/V8GCController.h"
#include "core/inspector/ConsoleMessage.h"
#include "core/testing/DummyPageHolder.h"
+#include "core/workers/InProcessWorkerObjectProxy.h"
#include "core/workers/WorkerBackingThread.h"
#include "core/workers/WorkerLoaderProxy.h"
-#include "core/workers/WorkerObjectProxy.h"
#include "core/workers/WorkerThreadStartupData.h"
#include "platform/ThreadSafeFunctional.h"
#include "platform/WaitableEvent.h"
@@ -24,8 +24,8 @@
namespace blink {
namespace {
-// A null WorkerObjectProxy, supplied when creating CompositorWorkerThreads.
-class TestCompositorWorkerObjectProxy : public WorkerObjectProxy {
+// A null InProcessWorkerObjectProxy, supplied when creating CompositorWorkerThreads.
+class TestCompositorWorkerObjectProxy : public InProcessWorkerObjectProxy {
public:
static PassOwnPtr<TestCompositorWorkerObjectProxy> create(ExecutionContext* context)
{
@@ -48,7 +48,7 @@ public:
private:
TestCompositorWorkerObjectProxy(ExecutionContext* context)
- : WorkerObjectProxy(nullptr)
+ : InProcessWorkerObjectProxy(nullptr)
, m_executionContext(context)
{
}
@@ -132,7 +132,7 @@ private:
OwnPtr<DummyPageHolder> m_page;
RefPtr<SecurityOrigin> m_securityOrigin;
- OwnPtr<WorkerObjectProxy> m_objectProxy;
+ OwnPtr<InProcessWorkerObjectProxy> m_objectProxy;
CompositorWorkerTestPlatform m_testPlatform;
};
« no previous file with comments | « third_party/WebKit/Source/modules/compositorworker/CompositorWorkerThread.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698